@@ -56,7 +56,7 @@
 #ifdef HAVE_NETDB_H
 #include <netdb.h>
 #endif
-#if HAVE_UNISTD_H
+#ifdef HAVE_UNISTD_H
 #include <unistd.h>
 #endif
 #ifdef HAVE_IO_H
@@ -664,6 +664,7 @@ int main(int argc, char **argv)
     cleanup_ctlTable( ss, index, indexlen );
 
     snmp_close(ss);
+    netsnmp_cleanup_session(&session);
     SOCK_CLEANUP;
     return 0;
 }
